<% if @ssl_proxyengine -%>

  # SSL Proxy directives
  SSLProxyEngine On
  <%- if @ssl_proxy_verify -%>
  SSLProxyVerify <%= @ssl_proxy_verify %>
  <%- end -%>
  <%- if @ssl_proxy_verify_depth -%>
  SSLProxyVerifyDepth <%= @ssl_proxy_verify_depth %>
  <%- end -%>
  <%- if @ssl_proxy_ca_cert -%>
  SSLProxyCACertificateFile "<%= @ssl_proxy_ca_cert %>"
  <%- end -%>
  <%- if @ssl_proxy_check_peer_cn -%>
  SSLProxyCheckPeerCN     <%= @ssl_proxy_check_peer_cn %>
  <%- end -%>
  <%- if @ssl_proxy_check_peer_name -%>
  SSLProxyCheckPeerName   <%= @ssl_proxy_check_peer_name %>
  <%- end -%>
  <%- if @ssl_proxy_check_peer_expire -%>
  SSLProxyCheckPeerExpire   <%= @ssl_proxy_check_peer_expire %>
  <%- end -%>
  <%- if @ssl_proxy_machine_cert -%>
  SSLProxyMachineCertificateFile "<%= @ssl_proxy_machine_cert %>"
  <%- end -%>
  <%- if @ssl_proxy_cipher_suite -%>
  SSLProxyCipherSuite <%= @ssl_proxy_cipher_suite %>
  <%- end -%>
  <%- if @ssl_proxy_protocol -%>
  SSLProxyProtocol  <%= [@ssl_proxy_protocol].flatten.compact.join(' ') %>
  <%- end -%>
<% end -%>
