<Location /ldap-status>
    SetHandler ldap-status
    <%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
    Require ip 127.0.0.1 ::1
    <%- else -%>
    Order deny,allow
    Deny from all
    Allow from 127.0.0.1 ::1
    Satisfy all
    <%- end -%>
</Location>
<% if @ldap_trusted_global_cert_file -%>
LDAPTrustedGlobalCert <%= @ldap_trusted_global_cert_type %> <%= @ldap_trusted_global_cert_file %>
<% end -%>
<% if @ldap_trusted_mode -%>
LDAPTrustedMode <%= @ldap_trusted_mode %>
<% end -%>
<%- if @ldap_shared_cache_size -%>
LDAPSharedCacheSize <%= @ldap_shared_cache_size %>
<%- end -%>
<%- if @ldap_cache_entries -%>
LDAPCacheEntries <%= @ldap_cache_entries %>
<%- end -%>
<%- if @ldap_cache_ttl -%>
LDAPCacheTTL <%= @ldap_cache_ttl %>
<%- end -%>
<%- if @ldap_opcache_entries -%>
LDAPOpCacheEntries <%= @ldap_opcache_entries %>
<%- end -%>
<%- if @ldap_opcache_ttl -%>
LDAPOpCacheTTL <%= @ldap_opcache_ttl %>
<%- end -%>
