<IfModule mod_userdir.c>
<% if @disable_root -%>
  UserDir disabled root
<% end -%>
  UserDir <%= @_path %>

  <Directory "<%= @_path %>">
    AllowOverride <%= @overrides.join(' ') %>
    Options <%= @options.join(' ') %>
    <Limit GET POST OPTIONS>
      <%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
      Require all granted
      <%- else -%>
      Order allow,deny
      Allow from all
      <%- end -%>
    </Limit>
    <LimitExcept GET POST OPTIONS>
      <%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
      Require all granted
      <%- else -%>
      Order allow,deny
      Allow from all
      <%- end -%>
    </LimitExcept>
  </Directory>
</IfModule>
