# ************************************
# Vhost template in module puppetlabs-apache
# Managed by Puppet
# ************************************

<VirtualHost <%= [@nvh_addr_port].flatten.compact.join(' ') %>>
<% if @servername and not @servername.empty? -%>
  ServerName <%= @servername %>
<% end -%>
<% if @serveradmin -%>
  ServerAdmin <%= @serveradmin %>
<% end -%>
