<IfModule alias_module>
Alias /icons/ "<%= @icons_path %>/"
<Directory "<%= @icons_path %>">
    Options <%= @icons_options %>
    AllowOverride None
<%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
    Require all granted
<%- else -%>
     Order allow,deny
     Allow from all
<%- end -%>
</Directory>
</IfModule>
