<% if @passenger_spawn_method -%>
  PassengerSpawnMethod <%= @passenger_spawn_method %>
<% end -%>
<% if @passenger_app_root -%>
  PassengerAppRoot <%= @passenger_app_root %>
<% end -%>
<% if @passenger_app_env -%>
  PassengerAppEnv <%= @passenger_app_env %>
<% end -%>
<% if @passenger_ruby -%>
  PassengerRuby <%= @passenger_ruby %>
<% end -%>
<% if @passenger_min_instances -%>
  PassengerMinInstances <%= @passenger_min_instances %>
<% end -%>
<% if @passenger_max_requests -%>
  PassengerMaxRequests <%= @passenger_max_requests %>
<% end -%>
<% if @passenger_start_timeout -%>
  PassengerStartTimeout <%= @passenger_start_timeout %>
<% end -%>
<% if @passenger_pre_start -%>
  PassengerPreStart <%= @passenger_pre_start %>
<% end -%>
<% if @passenger_user -%>
  PassengerUser <%= @passenger_user %>
<% end -%>
<% if @passenger_high_performance -%>
  PassengerHighPerformance <%= scope.call_function('apache::bool2httpd', [@passenger_high_performance]) %>
<% end -%>
<% if @passenger_nodejs -%>
  PassengerNodejs <%= @passenger_nodejs -%>
<% end -%>
<% if @passenger_sticky_sessions -%>
  PassengerStickySessions <%= scope.call_function('apache::bool2httpd', [@passenger_sticky_sessions]) %>
<% end -%>
<% if @passenger_startup_file -%>
  PassengerStartupFile <%= @passenger_startup_file -%>
<% end -%>
