<% if @cas_enabled -%>
  <%- if @cas_cookie_path -%>
  CASCookiePath <%= @cas_cookie_path %>
  <%- end -%>
  <%- if @cas_login_url -%>
  CASLoginURL <%= @cas_login_url %>
  <%- end -%>
  <%- if @cas_validate_url -%>
  CASValidateURL <%= @cas_validate_url %>
  <%- end -%>
  <%- if @cas_version -%>
  CASVersion <%= @cas_version %>
  <%- end -%>
  <%- if @cas_debug -%>
  CASDebug <%= @cas_debug %>
  <%- end -%>
  <%- if @cas_certificate_path -%>
  CASCertificatePath <%= @cas_certificate_path %>
  <%- end -%>
  <%- if @cas_proxy_validate_url -%>
  CASProxyValidateURL <%= @cas_proxy_validate_url %>
  <%- end -%>
  <%- if @cas_validate_depth -%>
  CASValidateDepth <%= @cas_validate_depth %>
  <%- end -%>
  <%- if @cas_root_proxied_as -%>
  CASRootProxiedAs <%= @cas_root_proxied_as %>
  <%- end -%>
  <%- if @cas_cookie_entropy -%>
  CASCookieEntropy <%= @cas_cookie_entropy %>
  <%- end -%>
  <%- if @cas_timeout -%>
  CASTimeout <%= @cas_timeout %>
  <%- end -%>
  <%- if @cas_idle_timeout -%>
  CASIdleTimeout <%= @cas_idle_timeout %>
  <%- end -%>
  <%- if @cas_cache_clean_interval -%>
  CASCacheCleanInterval <%= @cas_cache_clean_interval %>
  <%- end -%>
  <%- if @cas_cookie_domain -%>
  CASCookieDomain <%= @cas_cookie_domain %>
  <%- end -%>
  <%- if @cas_cookie_http_only -%>
  CASCookieHttpOnly <%= @cas_cookie_http_only %>
  <%- end -%>
  <%- if @cas_authoritative -%>
  CASAuthoritative <%= @cas_authoritative %>
  <%- end -%>
  <%- if @cas_sso_enabled -%>
  CASSSOEnabled On
  <%- end -%>
  <%- if @cas_validate_saml -%>
  CASValidateSAML On
  <%- end -%>
  <%- if @cas_attribute_prefix -%>
  CASAttributePrefix <%= @cas_attribute_prefix %>
  <%- end -%>
  <%- if @cas_attribute_delimiter -%>
  CASAttributeDelimiter <%= @cas_attribute_delimiter %>
  <%- end -%>
  <%- if @cas_scrub_request_headers -%>
  CASScrubRequestHeaders On
  <%- end -%>
<%- end -%>
