<% if @jk_mounts and not @jk_mounts.empty? -%>

  <%- @jk_mounts.each do |jk| -%>
    <%- if jk.is_a?(Hash) -%>
      <%- if jk.has_key?('mount') and jk.has_key?('worker') -%>
  JkMount   <%= jk['mount'] %> <%= jk['worker'] %>
      <%- elsif jk.has_key?('unmount') and jk.has_key?('worker') -%>
  JkUnMount <%= jk['unmount'] %> <%= jk['worker'] %>
      <%- end -%>
    <%- end -%>
  <%- end -%>
<% end -%>
