<% if @headers and ! @headers.empty? -%>

  ## Header rules
  ## as per http://httpd.apache.org/docs/2.2/mod/mod_headers.html#header
  <%- Array(@headers).each do |header_statement| -%>
    <%- if header_statement != '' -%>
  Header <%= header_statement %>
    <%- end -%>
  <%- end -%>
<% end -%>
