<Location <%= @status_path %>>
    SetHandler server-status
    <%-# From Puppet 4.2 up, replace: -%>
    <%-# "scope.function_template(["apache/mod/<Template>"])" -%>
    <%-# with: -%>
    <%-# "scope.call_function('template', ["apache/mod/<Template>"])" -%>
    <%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
<%= scope.function_template(["apache/mod/_require.erb"]) -%>
    <%- else -%>
<%= scope.function_template(["apache/mod/_allow.erb"]) -%>
    <%- end -%>
</Location>
ExtendedStatus <%= @extended_status %>

<IfModule mod_proxy.c>
    # Show Proxy LoadBalancer status in mod_status
    ProxyStatus On
</IfModule>
