<% if @setenv and ! @setenv.empty? -%>

  ## SetEnv/SetEnvIf for environment variables
  <%- Array(@setenv).each do |envvar| -%>
  SetEnv <%= envvar %>
  <%- end -%>
<% end -%>
<% if @setenvif and ! @setenvif.empty? -%>
  <%- Array(@setenvif).each do |envifvar| -%>
  SetEnvIf <%= envifvar %>
  <%- end -%>
<% end -%>
<% if @setenvifnocase and ! @setenvifnocase.empty? -%>
  <%- Array(@setenvifnocase).each do |envifncvar| -%>
  SetEnvIfNoCase <%= envifncvar %>
  <%- end -%>
<% end -%>
