<IfModule mod_ssl.c>
  SSLRandomSeed startup builtin
  SSLRandomSeed startup file:/dev/urandom <%= @ssl_random_seed_bytes %>
  SSLRandomSeed connect builtin
  SSLRandomSeed connect file:/dev/urandom <%= @ssl_random_seed_bytes %>

  AddType application/x-x509-ca-cert .crt
  AddType application/x-pkcs7-crl    .crl

  SSLPassPhraseDialog <%= @ssl_pass_phrase_dialog %>
  SSLSessionCache "shmcb:<%= @ssl_sessioncache %>"
  SSLSessionCacheTimeout <%= @ssl_sessioncachetimeout %>
  <%- if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
  Mutex <%= @_ssl_mutex %>
    <%- if @ssl_compression -%>
  SSLCompression <%= scope.call_function('apache::bool2httpd', [@ssl_compression]) %>
    <%- end -%>
  <%- else -%>
  SSLMutex <%= @_ssl_mutex %>
  <%- end -%>
  SSLCryptoDevice <%= @ssl_cryptodevice %>
  SSLHonorCipherOrder <%= scope.call_function('apache::bool2httpd', [@_ssl_honorcipherorder]) %>
  <%- if @ssl_ca -%>
  SSLCACertificateFile    "<%= @ssl_ca %>"
  <%- end -%>
<% if scope.function_versioncmp([@_apache_version, '2.4']) >= 0 -%>
  SSLUseStapling <%= scope.call_function('apache::bool2httpd', [@ssl_stapling]) %>
  <%- if not @ssl_stapling_return_errors.nil? -%>
  SSLStaplingReturnResponderErrors <%= scope.call_function('apache::bool2httpd', [@ssl_stapling_return_errors]) %>
  <%- end -%>
  SSLStaplingCache "shmcb:<%= @stapling_cache %>"
<% end -%>
  SSLCipherSuite <%= @ssl_cipher %>
  SSLProtocol <%= @ssl_protocol.compact.join(' ') %>
<% if not @ssl_proxy_protocol.empty? -%>
  SSLProxyProtocol <%= @ssl_proxy_protocol.compact.join(' ') %>
<% end -%>
<% if @ssl_options -%>
  SSLOptions <%= @ssl_options.compact.join(' ') %>
<% end -%>
<%- if @ssl_openssl_conf_cmd -%>
  SSLOpenSSLConfCmd <%= @ssl_openssl_conf_cmd %>
<%- end -%>
</IfModule>
