<%- if @keepalive -%>
  KeepAlive <%= @keepalive %>
<%- end -%>
<%- if @keepalive_timeout -%>
  KeepAliveTimeout <%= @keepalive_timeout %>
<%- end -%>
<%- if @max_keepalive_requests -%>
  MaxKeepAliveRequests <%= @max_keepalive_requests %>
<%- end -%>
