<IfModule mpm_prefork_module>
  StartServers        <%= @startservers %>
  MinSpareServers     <%= @minspareservers %>
  MaxSpareServers     <%= @maxspareservers %>
  ServerLimit         <%= @serverlimit %>
  <%- if @maxrequestworkers -%>
  MaxRequestWorkers      <%= @maxrequestworkers %>
  <%- elsif @maxclients -%>
  MaxClients             <%= @maxclients %>
  <%- end -%>
  <%- if @maxconnectionsperchild -%>
  MaxConnectionsPerChild <%= @maxconnectionsperchild %>
  <%- elsif @maxrequestsperchild -%>
  MaxRequestsPerChild    <%= @maxrequestsperchild %>
  <%- end -%>
  ListenBacklog       <%= @listenbacklog %>
</IfModule>
