<% if @fastcgi_server -%>

  FastCgiExternalServer <%= @fastcgi_server %> -socket <%= @fastcgi_socket -%>
<%   unless @fastcgi_idle_timeout.nil? %> -idle-timeout <%= @fastcgi_idle_timeout %><% end %>
<% end -%>
<% if @fastcgi_dir -%>

  <Directory "<%= @fastcgi_dir %>">
    Options +ExecCGI
    AllowOverride All
    SetHandler fastcgi-script
  <%- if scope.function_versioncmp([@apache_version, '2.4']) >= 0 -%>
    Require all granted
  <%- else -%>
    Order allow,deny
    Allow From All
  <%- end -%>
    AuthBasicAuthoritative Off
  </Directory>

  AllowEncodedSlashes On
  ServerSignature Off
<% end -%>
