# The Passenger Apache module configuration file is being
# managed by Puppet and changes will be overwritten.
<IfModule mod_passenger.c>
  <%- if @passenger_allow_encoded_slashes -%>
  PassengerAllowEncodedSlashes <%= @passenger_allow_encoded_slashes %>
  <%- end -%>
  <%- if @passenger_app_env -%>
  PassengerAppEnv <%= @passenger_app_env %>
  <%- end -%>
  <%- if @passenger_app_group_name -%>
  PassengerAppGroupName <%= @passenger_app_group_name %>
  <%- end -%>
  <%- if @passenger_app_root -%>
  PassengerAppRoot "<%= @passenger_app_root %>"
  <%- end -%>
  <%- if @passenger_app_type -%>
  PassengerAppType <%= @passenger_app_type %>
  <%- end -%>
  <%- if @passenger_base_uri -%>
  PassengerBaseURI <%= @passenger_base_uri %>
  <%- end -%>
  <%- if @passenger_buffer_response -%>
  PassengerBufferResponse <%= @passenger_buffer_response %>
  <%- end -%>
  <%- if @passenger_buffer_upload -%>
  PassengerBufferUpload <%= @passenger_buffer_upload %>
  <%- end -%>
  <%- if @passenger_concurrency_model -%>
  PassengerConcurrencyModel <%= @passenger_concurrency_model %>
  <%- end -%>
  <%- if @passenger_data_buffer_dir -%>
  PassengerDataBufferDir "<%= @passenger_data_buffer_dir %>"
  <%- end -%>
  <%- if @passenger_debug_log_file -%>
  PassengerDebugLogFile <%= @passenger_debug_log_file %>
  <%- end -%>
  <%- if @passenger_debugger -%>
  PassengerDebugger <%= @passenger_debugger %>
  <%- end -%>
  <%- if @passenger_default_group -%>
  PassengerDefaultGroup <%= @passenger_default_group %>
  <%- end -%>
  <%- if @passenger_default_ruby -%>
  PassengerDefaultRuby "<%= @passenger_default_ruby %>"
  <%- end -%>
  <%- if @passenger_default_user -%>
  PassengerDefaultUser <%= @passenger_default_user %>
  <%- end -%>
  <%- if @passenger_disable_security_update_check -%>
  PassengerDisableSecurityUpdateCheck <%= @passenger_disable_security_update_check %>
  <%- end -%>
  <%- if @passenger_enabled -%>
  PassengerEnabled <%= @passenger_enabled %>
  <%- end -%>
  <%- if @passenger_error_override -%>
  PassengerErrorOverride <%= @passenger_error_override %>
  <%- end -%>
  <%- if @passenger_file_descriptor_log_file -%>
  PassengerFileDescriptorLogFile "<%= @passenger_file_descriptor_log_file %>"
  <%- end -%>
  <%- if @passenger_fly_with -%>
  PassengerFlyWith "<%= @passenger_fly_with %>"
  <%- end -%>
  <%- if @passenger_force_max_concurrent_requests_per_process -%>
  PassengerForceMaxConcurrentRequestsPerProcess <%= @passenger_force_max_concurrent_requests_per_process %>
  <%- end -%>
  <%- if @passenger_friendly_error_pages -%>
  PassengerFriendlyErrorPages <%= @passenger_friendly_error_pages %>
  <%- end -%>
  <%- if @passenger_group -%>
  PassengerGroup <%= @passenger_group %>
  <%- end -%>
  <%- if @passenger_high_performance -%>
  PassengerHighPerformance <%= @passenger_high_performance %>
  <%- end -%>
  <%- if @passenger_instance_registry_dir -%>
  PassengerInstanceRegistryDir "<%= @passenger_instance_registry_dir %>"
  <%- end -%>
  <%- if @passenger_load_shell_envvars -%>
  PassengerLoadShellEnvvars <%= @passenger_load_shell_envvars %>
  <%- end -%>
  <%- if @passenger_log_file -%>
  PassengerLogFile "<%= @passenger_log_file %>"
  <%- end -%>
  <%- if @passenger_log_level -%>
  PassengerLogLevel <%= @passenger_log_level %>
  <%- end -%>
  <%- if @passenger_lve_min_uid -%>
  PassengerLveMinUid <%= @passenger_lve_min_uid %>
  <%- end -%>
  <%- if @passenger_max_instances -%>
  PassengerMaxInstances <%= @passenger_max_instances %>
  <%- end -%>
  <%- if @passenger_max_instances_per_app -%>
  PassengerMaxInstancesPerApp <%= @passenger_max_instances_per_app %>
  <%- end -%>
  <%- if @passenger_max_pool_size -%>
  PassengerMaxPoolSize <%= @passenger_max_pool_size %>
  <%- end -%>
  <%- if @passenger_max_preloader_idle_time -%>
  PassengerMaxPreloaderIdleTime <%= @passenger_max_preloader_idle_time %>
  <%- end -%>
  <%- if @passenger_max_request_queue_size -%>
  PassengerMaxRequestQueueSize <%= @passenger_max_request_queue_size %>
  <%- end -%>
  <%- if @passenger_max_request_time -%>
  PassengerMaxRequestTime <%= @passenger_max_request_time %>
  <%- end -%>
  <%- if @passenger_max_requests -%>
  PassengerMaxRequests <%= @passenger_max_requests %>
  <%- end -%>
  <%- if @passenger_memory_limit -%>
  PassengerMemoryLimit <%= @passenger_memory_limit %>
  <%- end -%>
  <%- if @passenger_meteor_app_settings -%>
  PassengerMeteorAppSettings "<%= @passenger_meteor_app_settings %>"
  <%- end -%>
  <%- if @passenger_min_instances -%>
  PassengerMinInstances <%= @passenger_min_instances %>
  <%- end -%>
  <%- if @passenger_nodejs -%>
  PassengerNodejs "<%= @passenger_nodejs %>"
  <%- end -%>
  <%- if @passenger_pool_idle_time -%>
  PassengerPoolIdleTime <%= @passenger_pool_idle_time %>
  <%- end -%>
  <%- if @passenger_pre_start -%>
  PassengerPreStart <%= @passenger_pre_start %>
  <%- end -%>
  <%- if @passenger_python -%>
  PassengerPython "<%= @passenger_python %>"
  <%- end -%>
  <%- if @passenger_resist_deployment_errors -%>
  PassengerResistDeploymentErrors <%= @passenger_resist_deployment_errors %>
  <%- end -%>
  <%- if @passenger_resolve_symlinks_in_document_root -%>
  PassengerResolveSymlinksInDocumentRoot <%= @passenger_resolve_symlinks_in_document_root %>
  <%- end -%>
  <%- if @passenger_response_buffer_high_watermark -%>
  PassengerResponseBufferHighWatermark <%= @passenger_response_buffer_high_watermark %>
  <%- end -%>
  <%- if @passenger_restart_dir -%>
  PassengerRestartDir "<%= @passenger_restart_dir %>"
  <%- end -%>
  <%- if @passenger_rolling_restarts -%>
  PassengerRollingRestarts <%= @passenger_rolling_restarts %>
  <%- end -%>
  <%- if @passenger_root -%>
  PassengerRoot "<%= @passenger_root %>"
  <%- end -%>
  <%- if @passenger_ruby -%>
  PassengerRuby "<%= @passenger_ruby %>"
  <%- end -%>
  <%- if @passenger_security_update_check_proxy -%>
  PassengerSecurityUpdateCheckProxy <%= @passenger_security_update_check_proxy %>
  <%- end -%>
  <%- if @passenger_show_version_in_header -%>
  PassengerShowVersionInHeader <%= @passenger_show_version_in_header %>
  <%- end -%>
  <%- if @passenger_socket_backlog -%>
  PassengerSocketBacklog <%= @passenger_socket_backlog %>
  <%- end -%>
  <%- if @passenger_spawn_method -%>
  PassengerSpawnMethod <%= @passenger_spawn_method %>
  <%- end -%>
  <%- if @passenger_start_timeout -%>
  PassengerStartTimeout <%= @passenger_start_timeout %>
  <%- end -%>
  <%- if @passenger_startup_file -%>
  PassengerStartupFile "<%= @passenger_startup_file %>"
  <%- end -%>
  <%- if @passenger_stat_throttle_rate -%>
  PassengerStatThrottleRate <%= @passenger_stat_throttle_rate %>
  <%- end -%>
  <%- if @passenger_sticky_sessions -%>
  PassengerStickySessions <%= @passenger_sticky_sessions %>
  <%- end -%>
  <%- if @passenger_sticky_sessions_cookie_name -%>
  PassengerStickySessionsCookieName <%= @passenger_sticky_sessions_cookie_name %>
  <%- end -%>
  <%- if @passenger_thread_count -%>
  PassengerThreadCount <%= @passenger_thread_count %>
  <%- end -%>
  <%- if @passenger_use_global_queue -%>
  PassengerUseGlobalQueue <%= @passenger_use_global_queue %>
  <%- end -%>
  <%- if @passenger_user -%>
  PassengerUser <%= @passenger_user %>
  <%- end -%>
  <%- if @passenger_user_switching -%>
  PassengerUserSwitching <%= @passenger_user_switching %>
  <%- end -%>
  <%- if @rack_auto_detect -%>
  RackAutoDetect <%= @rack_auto_detect %>
  <%- end -%>
  <%- if @rack_base_uri -%>
  RackBaseURI <%= @rack_base_uri %>
  <%- end -%>
  <%- if @rack_env -%>
  RackEnv <%= @rack_env %>
  <%- end -%>
  <%- if @rails_allow_mod_rewrite -%>
  RailsAllowModRewrite <%= @rails_allow_mod_rewrite %>
  <%- end -%>
  <%- if @rails_app_spawner_idle_time -%>
  RailsAppSpawnerIdleTime <%= @rails_app_spawner_idle_time %>
  <%- end -%>
  <%- if @rails_auto_detect -%>
  RailsAutoDetect <%= @rails_auto_detect %>
  <%- end -%>
  <%- if @rails_base_uri -%>
  RailsBaseURI <%= @rails_base_uri %>
  <%- end -%>
  <%- if @rails_default_user -%>
  RailsDefaultUser <%= @rails_default_user %>
  <%- end -%>
  <%- if @rails_env -%>
  RailsEnv <%= @rails_env %>
  <%- end -%>
  <%- if @rails_framework_spawner_idle_time -%>
  RailsFrameworkSpawnerIdleTime <%= @rails_framework_spawner_idle_time %>
  <%- end -%>
  <%- if @rails_ruby -%>
  RailsRuby <%= @rails_ruby %>
  <%- end -%>
  <%- if @rails_spawn_method -%>
  RailsSpawnMethod <%= @rails_spawn_method %>
  <%- end -%>
  <%- if @rails_user_switching -%>
  RailsUserSwitching <%= @rails_user_switching %>
  <%- end -%>
  <%- if @wsgi_auto_detect -%>
  WsgiAutoDetect <%= @wsgi_auto_detect %>
  <%- end -%>
  <%- if @rails_autodetect -%>
  RailsAutoDetect <%= @rails_autodetect %>
  <%- end -%>
  <%- if @rack_autodetect -%>
  RackAutoDetect <%= @rack_autodetect %>
  <%- end -%>

</IfModule>
