<IfModule mpm_worker_module>
  ServerLimit         <%= @serverlimit %>
  StartServers        <%= @startservers %>
  ThreadLimit         <%= @threadlimit %>
  MaxClients          <%= @maxclients %>
  MinSpareThreads     <%= @minsparethreads %>
  MaxSpareThreads     <%= @maxsparethreads %>
  ThreadsPerChild     <%= @threadsperchild %>
  MaxRequestsPerChild <%= @maxrequestsperchild %>
  ListenBacklog       <%= @listenbacklog %>
</IfModule>
