ExpiresActive <%= scope.call_function('apache::bool2httpd', [@expires_active]) %>
<%- if ! @expires_default.nil? and ! @expires_default.empty? -%>
ExpiresDefault "<%= @expires_default %>"
<%- end -%>
<%- if ! @expires_by_type.nil? and ! @expires_by_type.empty? -%>
<%-   [@expires_by_type].flatten.each do |line| -%>
<%-     line.map do |type, seconds| -%>
ExpiresByType <%= type %> "<%= seconds -%>"
<%-     end -%>
<%-   end -%>
<%- end -%>
