<%- if @mellon_cache_size -%>
MellonCacheSize <%= @mellon_cache_size %>
<%- end -%>
<%- if @mellon_cache_entry_size -%>
MellonCacheEntrySize <%= @mellon_cache_entry_size %>
<%- end -%>
<%- if @mellon_lock_file -%>
MellonLockFile "<%= @mellon_lock_file %>"
<%- end -%>
<%- if @mellon_post_directory -%>
MellonPostDirectory "<%= @mellon_post_directory %>"
<%- end -%>
<%- if @mellon_post_ttl -%>
MellonPostTTL <%= @mellon_post_ttl %>
<%- end -%>
<%- if @mellon_post_size -%>
MellonPostSize <%= @mellon_post_size %>
<%- end -%>
<%- if @mellon_post_count -%>
MellonPostCount <%= @mellon_post_count %>
<%- end -%>
