<IfModule mpm_itk_module>
  StartServers        <%= @startservers %>
  MinSpareServers     <%= @minspareservers %>
  MaxSpareServers     <%= @maxspareservers %>
  ServerLimit         <%= @serverlimit %>
  MaxClients          <%= @maxclients %>
  MaxRequestsPerChild <%= @maxrequestsperchild %>
  <%- if (not @enablecapabilities.nil?) && (scope.function_versioncmp([@_apache_version, '2.4']) >= 0) -%>
  EnableCapabilities  <%= scope.function_bool2httpd([@enablecapabilities]) %>
  <%- end -%>
</IfModule>
